@@ -7,10 +7,10 @@ import gradio
 
 
 def load_ipython_extension(ipython):
-    demo = gradio.Blocks()
+    __demo = gradio.Blocks()
 
     @register_cell_magic
     def blocks(line, cell):
-        with demo.clear():
+        with __demo.clear():
             exec(cell)
-            demo.launch(quiet=True)
+            __demo.launch(quiet=True)
